@@ -27,10 +27,12 @@ double f;
  Numeral.printf("%2.2fcm", f/470);
 }
 
+
 #define WP2LATEX	1
 #define AMSSYMB		2
 #define LATEXSYM	4
 #define ACCENTS		8
+#define SCALEREL	16
 
 
 /* Special meaning of digits in the LATEX term:
@@ -46,6 +48,7 @@ double f;
 ** 9: advanced next argument with all xx_yy^zz stuffs (similiarly to 1)
 **
 ** #: converts following argument from number in WPUnits to pt
+** |: converts following argument from number in % to ratio
 ** @: output exactly next character e.g. number (@1 produces 1; @@ -> @)
 ** !: ignore following character - placeholder
 **
@@ -95,7 +98,7 @@ const struct FmlTranslationArray FmlTransTable[] =
    { "UNDERLINE", "5{1}", 0 },
 /* 8 char words */
    { "ANGSTROM", "\\AA", 0 },
-   { "SCALESYM", "scalesym1",0 },		/* no translation known */
+   { "SCALESYM", "\\scaleobj{|1}{2}", SCALEREL},   
    { "BIGOPLUS", "5", 0 },
    { "BIGSQCAP", "\\bigsqcap", WP2LATEX},	/* in WP2LaTeX style */
    { "BIGSQCUP", "5", 0 },
@@ -420,7 +423,7 @@ bool FixFormula(TconvertedPass1 *cq, string & EquStr, int & Braces, int & BegBra
  * @param[in]     EquStr	String that contains a formula.
  * @param[out]	  Braces	Amount of curly braces.
  * @param[out]	  BegBrace	Amount of unbalanced curly braces at the beginning. */
-static bool CheckFormulaLeftRight(const char *EquStr,int & Braces,int & BegBrace)
+static bool CheckFormulaLeftRight(const char *EquStr, int & Braces, int & BegBrace)
 {
 int len;
 
@@ -437,14 +440,20 @@ int len;
 
        if(!strncmp(EquStr,"left",4))
        {
-         Braces++;
-         len-=3; EquStr+=3;
+         if(!isalpha(EquStr[4]))	// there could be \leftarrow or something like this.
+         {
+           Braces++;
+           len-=3; EquStr+=3;
+         }
        }
        else if(!strncmp(EquStr,"right",5))
        {
-         Braces--;
-         if(BegBrace>Braces) BegBrace=Braces;
-         len-=4; EquStr+=4;
+         if(!isalpha(EquStr[5]))	// there could be \rightarrow or something like this.
+         {
+           Braces--;
+           if(BegBrace>Braces) BegBrace=Braces;
+           len-=4; EquStr+=4;
+         }
        }
      }
 
@@ -871,9 +880,9 @@ return(0);
  * @param[out]	  arg	Argument divided from formula. */
 bool RemoveLastArg(string & str, string & arg)
 {
-#ifdef DEBUG
-  fprintf(cq->log,"\n#RemoveLastArg(%s,%s) ", chk(str()), chk(arg())); fflush(cq->log);
-#endif
+//#ifdef DEBUG
+//  fprintf(cq->log,"\n#RemoveLastArg(%s,%s) ", chk(str()), chk(arg())); fflush(cq->log);
+//#endif
 int i,j;
 char c,LastC;
 
@@ -965,9 +974,9 @@ return(0);
  * @param[out]	  arg	Argument extracred from formula. */
 static bool RemoveAdvancedLastArg(string & str, string & arg)
 {
-#ifdef DEBUG
-  fprintf(cq->log,"\n#RemoveAdvancedLastArg(%s,%s) ", chk(str()), chk(arg()));fflush(cq->log);
-#endif
+//#ifdef DEBUG
+//  fprintf(cq->log,"\n#RemoveAdvancedLastArg(%s,%s) ", chk(str()), chk(arg()));fflush(cq->log);
+//#endif
 int i, j;
 char c, LastC;
 BYTE LastSupSub, LastCBrace;
@@ -1133,16 +1142,16 @@ void Interpret(TconvertedPass1 *cq, string & strB, string & strE,
 		  strB+=arg[1];
                   break;
 
-        case '#' : Numeral="";
-		   switch (seq[1])
+        case '|': switch(seq[1])
 			{
 			case '0':Numeral=arg[0];seq++;break;
 			case '1':Numeral=arg[1];seq++;break;
 			case '2':Numeral=arg[2];seq++;break;
 			case '3':Numeral=arg[3];seq++;break;
 			case '4':Numeral=arg[4];seq++;break;
+                        default: Numeral='|'; break;
 			};
-                   if(Numeral=="")
+                  if(Numeral=="")
 		   	{
 			if (cq->err != NULL)
 			    {
@@ -1150,12 +1159,40 @@ void Interpret(TconvertedPass1 *cq, string & strB, string & strE,
 			    fprintf(cq->err, _("\nWarning: Formula #%d - missing numeric argument or error in formula grammar!"),FormulaNo);
 			    cq->perc.Show();
 			    }
-                        strB+="0pt ";
+                        strB+="1";
 			break;
                         }
-                   WPU2cm(Numeral);
-                   strB+= Numeral;
-                   break;
+                  if(Numeral!="|")
+                      {
+                      double f = atof(Numeral()); 
+                      Numeral.printf("%2.2f", f/100);
+                      }
+                  strB += Numeral;
+                  break;
+
+        case '#': switch(seq[1])
+			{
+			case '0':Numeral=arg[0];seq++;break;
+			case '1':Numeral=arg[1];seq++;break;
+			case '2':Numeral=arg[2];seq++;break;
+			case '3':Numeral=arg[3];seq++;break;
+			case '4':Numeral=arg[4];seq++;break;
+			default: Numeral=""; break;
+			};
+                  if(Numeral=="")
+		   	{
+			if (cq->err != NULL)
+			    {
+			    cq->perc.Hide();
+			    fprintf(cq->err, _("\nWarning: Formula #%d - missing numeric argument or error in formula grammar!"),FormulaNo);
+			    cq->perc.Show();
+			    }
+                        strB += "0pt ";
+			break;
+                        }
+                  WPU2cm(Numeral);
+                  strB+= Numeral;
+                  break;
 
         case '!':seq++;			//ignore following character
 		 if(*seq==0) {seq--;break;}
@@ -1275,7 +1312,7 @@ bool MathArray = false;
 	if(Box.CaptionSize>0)
 		      {
 		      fseek(cq->wpd, Box.CaptionPos, SEEK_SET);
-		      cq->Dispatch(DISP_DO_CAPTION, Box.CaptionSize);
+		      cq->Dispatch(DISP_DO_CAPTION, &Box.CaptionSize);
 		      }
 	fprintf(cq->strip,"\\end{table}");
 	}
@@ -1332,10 +1369,76 @@ while(length(StrEnd)>0)
 }
 
 
+/// Chatacter "'" is expanded as ^{\prime}. Double '' causes error and must be fixed.
+string FixMultiplePrime(string Str)
+{
+const char *ch;
+int PrimeCount = 0;
+
+  if(Str.length()<=0) return Str;
+  ch = strchr(Str(), '\'');
+  while(ch!=NULL)
+  {
+    string PrimeList("^{\\prime");
+    PrimeCount++;
+    int Pos = ch - Str();
+    const char *ch2 = ch;
+
+    do
+      {      
+      ch2++;
+
+      if(*ch2 == 0) break;
+
+      if(*ch2 == '\'')
+        {
+        PrimeList += "\\prime";
+        PrimeCount++;
+        continue;
+        }
+
+      if(*ch2 == '^')
+        {
+        ch2++;
+        string TempTail(ch2);
+        string Arg;
+
+        Remove1stArg(TempTail, Arg);
+        if(Arg[0]!='\\') PrimeList += ' ';
+        PrimeList += Arg;
+        Str = copy(Str,0,Pos) + TempTail;
+        ch2 = Str() + Pos + 1;
+
+        PrimeCount++;
+        }
+
+      } while(isspace(*ch2) || *ch2==1 || *ch2=='\'');
+
+    if(PrimeCount>1)
+    {    
+      PrimeList += '}';
+      
+      int Pos2 = ch2 - Str();
+
+      //string temp1 = copy(Str,0,Pos);
+      //string temp2 = copy(Str,Pos2,Str.length()-Pos2);
+
+      Str = copy(Str,0,Pos) + PrimeList + copy(Str,Pos2,Str.length()-Pos2);
+      ch = strchr(Str()+Pos2, '\'');
+    }
+    else
+       ch = strchr(ch2, '\'');
+
+    PrimeCount = 0;      
+  }
+
+  return Str;
+}
+
+
 /** Main formula string converting and optimizing procedure. */
 bool OptimizeFormulaStr(TconvertedPass1 *cq, string & StrBeg)
 {
-//int xpos;
 int i, j;
 string StrEnd, arg[3];
 bool error = false;
@@ -1349,6 +1452,8 @@ BYTE styles;
 
   if(StrBeg == "") return(false);  /*equation is empty-nothing to do*/
 
+  StrBeg = replacesubstring(StrBeg,"\1}","\\}");              /*fix \} in WP -> \1 -> "\}"*/
+  StrBeg = replacesubstring(StrBeg,"\1{","\\{");              /*fix \} in WP -> \1 -> "\}"*/
   error = FixFormula(cq,StrBeg,i,j);
 
 	//Here starts an equation conversion phase
@@ -1405,6 +1510,10 @@ BYTE styles;
 		  {
 		  if(Accents>=false) {Accents=true; styles=0;}
 		  }
+                if((styles & SCALEREL) != 0)
+		  {
+		  if(Scalerel>=false) {Scalerel=true; styles=0;}
+		  }
 		if( (styles & LATEXSYM) != 0)
 		  {
 		  if ((LaTeX_Version & 0xFF00) >= 0x300)
@@ -1502,8 +1611,11 @@ BYTE styles;
 
   StrBeg += StrEnd; /* Prepare equation for writing */
   StrEnd = "";
-  StrBeg=replacesubstring(StrBeg,"\1\1","\\backslash");
-  StrBeg=replacesubstring(StrBeg,"\1"," ");              /*fix \ in WP -> \1 -> ' '*/
+
+  StrBeg = FixMultiplePrime(StrBeg);
+
+  StrBeg = replacesubstring(StrBeg,"\1\1","\\backslash");
+  StrBeg = replacesubstring(StrBeg,"\1"," ");              /*fix \ in WP -> \1 -> ' '*/
 
   if(error)
     StrBeg = _("% Formula error fixed by WP2LaTeX!\n") + StrBeg;
@@ -1624,8 +1736,12 @@ string & FixFormulaStrFromTeX(string & StrEnd, const char chr_set)
 	else StrEnd+=' ';
        }
   else {
-	if(chr_set==10) StrEnd="{\\cyr "+StrEnd+"}";
-		   else StrEnd="{\\rm "+StrEnd+"}";
+	if(chr_set==10)
+          {
+          StrEnd="{\\cyr "+StrEnd+"}";
+          Cyrillic = true;
+          }
+          else StrEnd="{\\rm "+StrEnd+"}";
        }
 
   string StrBeg;
