@@ -300,20 +300,21 @@ return(i);
 
 
 /** Convert a block of WP5.x text into PostScript. */
-static void Textl2_2PS(TconvertedPass1 *cq, long ldblk, string & PSData, PS_State *PSS, WPG_records *WPG)
+static void Textl2_2PS(TconvertedPass1 *cq, VectorList &VectList, long ldblk, PS_State &PSS, WPG_records *WPG)
 {
 #ifdef DEBUG
   fprintf(cq->log,"\n#Textl2_2PS() ");fflush(cq->log);
 #endif
 BYTE TextColorIdx;
 string Text;
-RGB_Record BkTextColor = PSS->TextColor;
+const RGB_Record BkTextColor = PSS.TextColor;
+const short BkFontSize = PSS.FontSize;
 WORD FontSize = 1100;		// Default font size
 long ActualPos;
 TconvertedPass1 *cq5;
 
   if(ldblk<=0) return;
-  cq5=GetConvertor("WP5.x");
+  cq5 = GetConvertor("WP5.x");
   if(cq5==NULL) 
     {
     if(cq->err!=NULL && Verbosing>=0)
@@ -324,6 +325,9 @@ TconvertedPass1 *cq5;
     return;
     }
 
+  TextContainer *pTextCont = new TextContainer;  
+  //pTextCont->FontOrientation = PSS.FontOrientation10 / 10.0f;
+
   cq5->InitMe(cq->wpd,cq->table,cq->strip,cq->log,cq->err);
   cq5->recursion++;
   if(cq5->ConvertCpg==NULL)
@@ -369,36 +373,33 @@ TconvertedPass1 *cq5;
         Rd_word(cq5->wpd, &FontSize2);
         sprintf(cq5->ObjType,"Font Size %dWPu",FontSize2);
 
-        if(length(Text)<=0)	// 1st font size change
-	  FontSize = FontSize2;
-        else
+        if(FontSize2!=FontSize)
           {
-          if(FontSize2!=FontSize)
+          if(length(Text)>0)  
             {
-            Text += ") show\n";
-            Font2PS(PSData,FontSize2/50.0f);	// Convert WPGu to points.
-            Text += "\n(";
+            pTextCont->AddText(Text,PSS);
+            Text.erase();
             }
-	  }
+                  
+          FontSize = FontSize2;
+          PSS.FontSize = WPGu2mm(FontSize);
+	  }        
 	}
       if(cq5->subby==2)
 	{
 	fseek(cq5->wpd,1+2,SEEK_CUR);
 	TextColorIdx = fgetc(cq5->wpd);
-	if(length(Text)<=0)	// 1st color change
+
+        RGB_Record NewColor = WPG_Palette[TextColorIdx];
+        if(memcmp(&NewColor,&PSS.TextColor,sizeof(PSS.TextColor)))
           {
-	  PSS->TextColor = WPG_Palette[TextColorIdx];
+          if(length(Text)>0)
+            {
+            pTextCont->AddText(Text,PSS);
+            Text.erase();
+            }        
+	  PSS.TextColor = NewColor;
           }
-        else  // The color might be changed more than once.
-          {
-          RGB_Record NewColor = WPG_Palette[TextColorIdx];
-          if(memcmp(&NewColor,&PSS->TextColor,sizeof(PSS->TextColor)))
-            {            
-            Text += ") show\n";
-	    Color2PS(Text,NewColor);
-            Text += " (";
-            }
-	  }
 	}
       fseek(cq5->wpd,ActualPos,SEEK_SET);
       }
@@ -409,11 +410,28 @@ TconvertedPass1 *cq5;
  if(cq5!=cq)
 	delete cq5;
 
- StoreText2PS(PSData,Text,PSS,WPG->TextL2.RotAngle,
+ if(Text.length()>0)
+ {
+   pTextCont->AddText(Text,PSS);
+   Text.erase();
+ }
+
+ if(!pTextCont->isEmpty())
+ {
+   pTextCont->PosX = WPGu2PSu(WPG->TextL2.LowLeftX);
+   pTextCont->PosY = WPGu2PSu(WPG->TextL2.LowLeftY);
+   pTextCont->FontOrientation = WPG->TextL2.RotAngle;
+   VectList.AddObject(pTextCont);
+ }
+ else
+   delete pTextCont;
+
+ /* StoreText2PS(PSData,Text,PSS,WPG->TextL2.RotAngle,
 	      WPGu2PSu(WPG->TextL2.UpRightX),WPGu2PSu(WPG->TextL2.UpRightY),
 	      WPGu2PSu(WPG->TextL2.LowLeftX),WPGu2PSu(WPG->TextL2.LowLeftY),
-	      FontSize/50.0/2.66);
- PSS->TextColor = BkTextColor;
+	      FontSize/50.0/2.66); */
+ PSS.TextColor = BkTextColor;
+ PSS.FontSize = BkFontSize;
 }
 
 
@@ -1064,8 +1082,7 @@ vecResizeCTM TRx;
 	      //CrackObject(cq,NewObject);//!!!!
 	      TRx.LoadWPG2Flags(cq->wpd,StartWPG.PosSizePrecision);	      
               //printf("\n Rot angle = %f    ", RotAngle);
-
-              float UpRightX, UpRightY;
+              
               float Sx, Sy;
               float RightX, RightY;
               float TopX, TopY;                  
@@ -1637,7 +1654,7 @@ LoadRaster:	      if(CurrImg->Raster!=NULL)
 			Rd_word(cq->wpd,(WORD *)&WPG.TextL2.UpRightY);
 			UpdateBBox(bbx, WPG.TextL2.RotAngle,
 				   WPG.TextL2.LowLeftX,WPG.TextL2.LowLeftY,WPG.TextL2.UpRightX-WPG.TextL2.LowLeftX,WPG.TextL2.UpRightY-WPG.TextL2.LowLeftY);
-			Textl2_2PS(cq,ldblk,PSData, &PSS,&WPG);
+			Textl2_2PS(cq,VectList,ldblk,PSS,&WPG);
 			}
 		      strcpy(cq->ObjType,"Graphics Text l2");
 		      break;
@@ -1789,17 +1806,37 @@ LoadRaster:	      if(CurrImg->Raster!=NULL)
       else	// SrcImage != NULL
           {
           fseek(cq->wpd,Box.Image_offset,SEEK_SET);
-          for(i=0; i<Box.Image_size; i++)
-	    {
-	    ch = fgetc(cq->wpd);
-	    fputc(ch,SrcImage);
-	    }
+          CopyFile(SrcImage, cq->wpd, Box.Image_size);          
           fclose(SrcImage);
-          }
+
+          SrcImage = fopen(NewFilename(),"rb");
+          if(SrcImage)
+            {
+            CheckFileFormat(SrcImage,FilForD);
+            fclose(SrcImage);
+            
+            const char *Ext = GetExtension(NewFilename());
+            if(FilForD.Extension!=NULL && Ext!=NULL)
+              {
+              if(*Ext=='.') Ext++;
+              if(stricmp(Ext,FilForD.Extension))
+                {
+                if(cq->err!=NULL && Verbosing>=0)
+	          {
+	          cq->perc.Hide();
+	          fprintf(cq->err, _("\nError: File '%s' has wrong extension, should be used '%s'!"), NewFilename(), FilForD.Extension);
+                  }
+                string FileNameFix(copy(NewFilename(),0,Ext-NewFilename()) + FilForD.Extension);
+                rename(NewFilename(), FileNameFix());
+                NewFilename = FileNameFix;
+                }
+	     }            
+           }
+         }
       }
 
     fseek(cq->wpd,Box.Image_offset+Hdr.DataOffset,SEEK_SET);
-    cq->ActualPos=Box.Image_offset+Hdr.DataOffset;
+    cq->ActualPos = Box.Image_offset+Hdr.DataOffset;
     StartWPG2.PosSizePrecision = 0;
     PSS.LineStyle = 0;		// No contour line as default.
     PSS.FirstTimeFix = true;
@@ -1940,6 +1977,8 @@ Image Img;
 return LoadPicture(Name);
 }
 
+
+/** Check whether file contains WPG2 stream of objects without header. */
 bool CheckWPG2WithoutPrefix(FILE *F, size_t BlobSize)
 {
 WPG2Record Rec2;
@@ -2219,7 +2258,7 @@ FileIsOK:
           if(cq->err!=NULL && Verbosing>=0)
 	  {
 	    cq->perc.Hide();
-	    fprintf(cq->err, _("\nError: Existing caption cannot be formated into a current order of objects."));
+	    fprintf(cq->err, _("\nError: Existing caption cannot be inserted into a current order of objects."));
 	  }
         }
       Box.CaptionSize = 0;
