@@ -434,7 +434,7 @@ public: Raster2DAbstract *Raster;
 
 	Image(void): VecImage(NULL)  {RotAngle=x=y=dx=dy=0;Raster=NULL;Next=NULL;Palette=NULL;};
 	Image(const Image & I, bool AllFrames=true);
-	Image(Raster2DAbstract *NewRaster): VecImage(NULL) {x=y=dx=dy=0;Next=NULL;Palette=NULL;if((Raster=NewRaster)!=NULL) Raster->UsageCount++;};
+	Image(Raster2DAbstract *NewRaster): VecImage(NULL) {RotAngle=x=y=dx=dy=0;Next=NULL;Palette=NULL;if((Raster=NewRaster)!=NULL) Raster->UsageCount++;};
 	~Image(void) {Erase();};
 	IMAGE_TYPE ImageType(void) const;   // 0-none, 1-gray, 2-palette, 3-true color
 
