@@ -13,6 +13,7 @@
 #include "common.h"
 
 #include "raster.h"
+#include "vecimage.h"
 #include "ras_prot.h"
 
 #ifdef _MSC_VER  
@@ -51,10 +52,9 @@ Image::Image(const Image & I, bool AllFrames)
 {
  if((Raster=I.Raster)!=NULL) Raster->UsageCount++;
  if((Palette=I.Palette)!=NULL) Palette->UsageCount++;
+ if((VecImage=I.VecImage)!=NULL) VecImage->UsageCount++;
  x=I.x; y=I.y; dx=I.dx; dy=I.dy; RotAngle=I.RotAngle;
- Next = NULL; 
- Comment = NULL;
- if(I.Comment!=NULL) Comment=strdup(I.Comment);
+ Next = NULL;  
 
  if(AllFrames)
  {
@@ -73,8 +73,7 @@ Image::Image(const Image & I, bool AllFrames)
 
 Raster2DAbstract *Image::operator=(Raster2DAbstract *NewRaster)
 {
- x=y=dx=dy=0;
- Comment=NULL;
+ x=y=dx=dy=0; 
  if(Raster==NewRaster) return(Raster);		//Identical assignment
  if(Raster!=NULL) Erase();
  if( (Raster=NewRaster)!=NULL ) Raster->UsageCount++;
@@ -87,15 +86,15 @@ Image *PImg;
 const Image *CurrImg;
  Erase();
 
- PImg=this;
- CurrImg=&I;
+ PImg = this;
+ CurrImg = &I;
  goto CopyImg;
 
  while(CurrImg!=NULL)	//Multiple images
 	{
-	PImg->Next=new Image;
+	PImg->Next = new Image;
 	if(PImg->Next==NULL) return(*this);
-	PImg=PImg->Next;
+	PImg = PImg->Next;
 
 CopyImg:if((PImg->Raster=CurrImg->Raster)!=NULL)
 		CurrImg->Raster->UsageCount++;
@@ -104,8 +103,9 @@ CopyImg:if((PImg->Raster=CurrImg->Raster)!=NULL)
 	PImg->x=CurrImg->x;PImg->y=CurrImg->y;
 	PImg->dx=CurrImg->dx;PImg->dy=CurrImg->dy;
 	PImg->RotAngle=CurrImg->RotAngle;
-	if(CurrImg->Comment!=NULL) PImg->Comment=strdup(CurrImg->Comment);
-	CurrImg=CurrImg->Next;
+        if((PImg->VecImage=CurrImg->VecImage)!=NULL)
+                CurrImg->VecImage->UsageCount++;
+	CurrImg = CurrImg->Next;
 	}
  return(*this);
 }
@@ -115,27 +115,27 @@ void Image::Erase(void)
 {
 Image *I,*OldI;
 
- I=this;
+ I = this;
  while(I!=NULL)
    {
    if(I->Raster!=NULL)
       {
       if(I->Raster->UsageCount--<=1) delete I->Raster;
-      I->Raster=NULL;
+      I->Raster = NULL;
       }
    if(I->Palette!=NULL)
       {
       if(I->Palette->UsageCount--<=1) delete I->Palette;
-      I->Palette=NULL;
+      I->Palette = NULL;
       }
-   if(I->Comment!=NULL)
+   if(I->VecImage!=NULL)
       {
-      free(I->Comment);
-      I->Comment=NULL;
+      if(I->VecImage->UsageCount--<=1) delete I->VecImage;      
+      I->VecImage = NULL;
       }
-   OldI=I;
-   I=I->Next;
-   OldI->Next=NULL;
+   OldI = I;
+   I = I->Next;
+   OldI->Next = NULL;
    if(OldI!=this) delete(OldI);
    }
 }
@@ -217,6 +217,21 @@ void Image::AttachPalette(APalette *NewPalette)
 }
 
 
+void Image::AttachVecImg(VectorImage *NewVecImg)
+{
+  if(VecImage==NewVecImg) return;		// Raster is already attached
+  if(VecImage!=NULL)			// Detach previously attached raster
+   {
+   if(VecImage->UsageCount--<=1) delete VecImage;
+   VecImage = NULL;
+   }
+  if(NewVecImg!=NULL)			// Attach raster now
+   {
+   VecImage=NewVecImg; VecImage->UsageCount++;
+   }
+}
+
+
 /* ---------------------------- */
 
 
