@@ -1082,8 +1082,7 @@ TextContainer::TextContainer()
 {
   Text = NULL;
   TextObjects = 0;
-  FontOrientation = 0;
-  TextColor.Red = TextColor.Green = TextColor.Blue = 0;		// Use black.
+  FontOrientation = 0;  
 }
 
 
@@ -1109,19 +1108,15 @@ TextContainer::~TextContainer()
 temp_string TextContainer::Export2EPS(PS_State *PSS) const
 {
 temp_string str;
+RGB_Record BkTextColor;
 
   if(Text!=NULL && TextObjects>0)
   {
     if(PSS!=NULL)
-    {
-      if(memcmp(&TextColor,&PSS->LineColor,sizeof(RGB_Record)) != 0) 
-      {			// EPS does not handle separatelly text color and line color.
-        PSS->dirty |= PSS_LineColor;
-        memcpy(&PSS->LineColor,&TextColor,sizeof(RGB_Record));
-      }    
-      PS_Attr(str,PSS);
+    {    
+      PS_Attr(str,PSS);   
+      memcpy(&BkTextColor,&PSS->LineColor,sizeof(RGB_Record));
     }
-
     if(fabs(FontOrientation) > 0.01)    
         str += "\ngsave";    
 
@@ -1135,8 +1130,20 @@ temp_string str;
         FixPsAccent(Text[i]->contents,"\\`{","(\\301)");	// grave
 
         if(i>0) str += "\nshow";
-        str.cat_printf("\n/%s findfont %.2f scalefont setfont",
-            Text[i]->TargetFont(), Text[i]->size*2.66f);
+
+        if(PSS!=NULL)
+        {
+          if(memcmp(&Text[i]->TextColor,&PSS->LineColor,sizeof(RGB_Record)) != 0) 
+          {			// EPS does not handle separatelly text color and line color.
+            PSS->dirty |= PSS_LineColor;
+            memcpy(&PSS->LineColor,&Text[i]->TextColor,sizeof(RGB_Record));
+            PS_Attr(str,PSS);
+          }
+        }
+
+        if(i==0 || fabs(Text[i]->size-Text[i-1]->size)>1e-3)
+          str.cat_printf("\n/%s findfont %.2f scalefont setfont",
+                         Text[i]->TargetFont(), Text[i]->size*2.66f);
 
         if(i==0)
         {
@@ -1150,8 +1157,12 @@ temp_string str;
       }      
     }
     str += "\nshow";
-    if(fabs(FontOrientation) > 0.01)    
-        str += "\ngrestore";    
+    if(fabs(FontOrientation) > 0.01)
+    {    
+      str += "\ngrestore";
+      if(PSS)   
+        memcpy(&PSS->LineColor,&BkTextColor,sizeof(RGB_Record));
+    }
   }
 
 return str;
@@ -1172,7 +1183,7 @@ void TextContainer::AddText(temp_string contents, const PS_State &PSS)
     PsFontName = (PSS.FontWeight>=500) ? "Times-BoldItalic" : "Times-Italic";
   else
     PsFontName = (PSS.FontWeight>=500) ? "Times-Bold" : "Times-Roman";
-
+  
   for(int i=0; i<sizeof(GreekText)/sizeof(char*); i++)
     {
     if(!StrCmp(contents,GreekText[i]))
@@ -1199,12 +1210,14 @@ TextObject *pTobj;
     pTobj->contents = contents;
     pTobj->size = PSS.FontSize;
     //pTobj->Weight = Weight;
+    memcpy(&pTobj->TextColor,&PSS.TextColor,sizeof(RGB_Record));  
     TextObjects = 1;
     return;
   }
 
   pTobj = Text[TextObjects-1];
-  if(pTobj->TargetFont==font && fabs(pTobj->size-PSS.FontSize)<1e-4)	//&& pTobj->Weight==Weight
+  if(pTobj->TargetFont==font && fabs(pTobj->size-PSS.FontSize)<1e-4 && 
+     memcmp(&PSS.TextColor,&pTobj->TextColor,sizeof(RGB_Record))==0)	//&& pTobj->Weight==Weight
   {
     pTobj->contents += contents;
     return;
@@ -1221,8 +1234,10 @@ TextObject *pTobj;
   pTobj = Text[TextObjects-1] = new TextObject;
   pTobj->TargetFont = font;
   pTobj->contents = contents;
+  
   pTobj->size = PSS.FontSize;
-  //pTobj->Weight = Weight;
+    //pTobj->Weight = Weight;  
+  memcpy(&pTobj->TextColor,&PSS.TextColor,sizeof(RGB_Record));  
 }
 
 
