@@ -110,8 +110,6 @@ JobBase *JOB = NULL;
 
 int InitJobs(int ThrCount)
 {
-unsigned tid;
-
   if(ThrCount<0)
     {
     const char *str = getenv("OMP_NUM_THREADS");
@@ -146,7 +144,7 @@ unsigned tid;
   {
 #ifdef _WIN32
      HANDLE thread;
-     thread = (HANDLE)_beginthreadex(NULL,0,&JobThread,0,0,&tid);
+     thread = (HANDLE)_beginthreadex(NULL,0,&JobThread,0,0,NULL);
 #else
      pthread_t WriteThread;
      pthread_create(&WriteThread, NULL, JobThread, NULL);
