@@ -274,7 +274,7 @@ void AttrOff(TconvertedPass1 *cq, char attr_num)
 string s;
 
  _AttrOff(cq->attr,attr_num,s);
- if(s!="") fputs(s,cq->strip);
+ if(s!="") fputs(s(),cq->strip);
 
  if(attr_num==Heb_Font && cq->Font==FONT_HEBREW)
    {
@@ -347,7 +347,7 @@ void Attr_OFF(TconvertedPass1 *cq, unsigned char b)
   if ((b==7) && ((LaTeX_Version & 0xFF00) < 0x300))  goto RejectAttr;
 
   _AttrOff(cq->attr,b & 0xF,s);
-  if(s!="") fputs(s,cq->strip);
+  if(s!="") fputs(s(),cq->strip);
 
 RejectAttr:
   sprintf(cq->ObjType, "Attr %d Off",(int)b);
@@ -1061,7 +1061,7 @@ void EndSection(TconvertedPass1 *cq, signed char WP)
 
   if(OptimizeSection && cq->envir!='B') _AttrOff(cq->attr,b,s);
 				   else _AttrOff(cq->attr,Last_com_section+1,s);
-  if(s!="") fputs(s,cq->strip);
+  if(s!="") fputs(s(),cq->strip);
 }
 
 
