@@ -143,8 +143,6 @@ typedef struct 		//symbol
 #define ecEndOfFile         7	// End of file reached while reading RTF
 
 
-void AttrFit(attribute & Base, attribute & A_New, string & s);
-
 class TconvertedPass1_RTF: public TconvertedPass1
        {
 public:CpTranslator *Unicode;
@@ -1006,7 +1004,7 @@ static void FootnoteRTF(TconvertedPass1_RTF *cq)
 
   Close_All_Attr(cq->attr,cq->strip);
   OldAttr=cq->attr;
-  InitAttr(cq->attr);
+  cq->attr.InitAttr();
 
   cq->ActualPos = ftell(cq->wpd);
   cq->subby=RTFLoadKeyword(cq);
@@ -1153,7 +1151,7 @@ static void HeaderFooterRTF(TconvertedPass1_RTF *cq, unsigned char HFtype)
   OldEnvir= cq->envir;
 
 // Start a conversion of a Header or Footer
-  InitAttr(cq->attr);		//Turn all attributes in the header/footer off
+  cq->attr.InitAttr();		//Turn all attributes in the header/footer off
   cq->recursion++;
 
   cq->line_term = 's';    	//Soft return
@@ -1248,7 +1246,7 @@ static void IndexRTF(TconvertedPass1_RTF *cq)
 
   Close_All_Attr(cq->attr,cq->strip);
   OldAttr=cq->attr;
-  InitAttr(cq->attr);
+  cq->attr.InitAttr();
 
   cq->ActualPos = ftell(cq->wpd);
   fputs(" \\index{", cq->strip);
