@@ -1033,8 +1033,7 @@ TEXT_OUT_FAIL:
   if(!CheckWmfRecSz((StringLen+1)/2)) goto TEXT_OUT_FAIL;
   
   const float Scale = GetScale2PSU((TMapMode)MapMode);  
-  TextContainer *pTextCont = new TextContainer;
-  memcpy(&pTextCont->TextColor, &PSS.TextColor, sizeof(pTextCont->TextColor));
+  TextContainer *pTextCont = new TextContainer;  
   pTextCont->PosX = 0;
   pTextCont->PosY = 0;
   pTextCont->FontOrientation = PSS.FontOrientation10 / 10.0f;
@@ -1057,7 +1056,6 @@ TEXT_OUT_FAIL:
         const float CurPosY = pTextCont->PosY + mm2PSu(PSS.FontSize);
         VectList.AddObject(pTextCont);
         pTextCont = new TextContainer;
-        memcpy(&pTextCont->TextColor, &PSS.TextColor, sizeof(pTextCont->TextColor));
         pTextCont->PosX = 0;
         pTextCont->PosY = CurPosY;
         pTextCont->FontOrientation = PSS.FontOrientation10 / 10.0f;
@@ -1073,7 +1071,7 @@ TEXT_OUT_FAIL:
       {
         const char *str = Ext_chr_str((char)ch, this, ConvertCpg);
         if(str==NULL)       
-          pTextCont->AddText("_",PSS);        
+          pTextCont->AddText("_",PSS);
         else        
           pTextCont->AddText(str,PSS);        
       }
@@ -1152,8 +1150,7 @@ unsigned char c;
   }
 
   const float Scale = GetScale2PSU((TMapMode)MapMode);
-  TextContainer *pTextCont = new TextContainer;
-  memcpy(&pTextCont->TextColor, &PSS.TextColor, sizeof(pTextCont->TextColor));
+  TextContainer *pTextCont = new TextContainer;  
   pTextCont->PosX = Scale*x_pos;
   pTextCont->PosY = Scale*y_pos;
   pTextCont->FontOrientation = PSS.FontOrientation10 / 10.0f;
@@ -1174,8 +1171,7 @@ unsigned char c;
       {
         const float CurPosY = pTextCont->PosY + mm2PSu(PSS.FontSize);
         VectList.AddObject(pTextCont);
-        pTextCont = new TextContainer;
-        memcpy(&pTextCont->TextColor, &PSS.TextColor, sizeof(pTextCont->TextColor));
+        pTextCont = new TextContainer;        
         pTextCont->PosX = Scale*x_pos;        
         pTextCont->PosY = CurPosY;
         pTextCont->FontOrientation = PSS.FontOrientation10 / 10.0f;
