@@ -10,19 +10,19 @@
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdarg.h>
 
 #include <ctype.h>
 
-#include <sets.h>
-#include <lists.h>
-#include <stringa.h>
+#include "sets.h"
+#include "lists.h"
+#include "stringa.h"
 
 #ifdef __UNIX__
  #include <unistd.h>
 #endif
 
 #include "wp2latex.h"
+#include "struct.h"
 #include "cole/cole.h"
 #include "cp_lib/cptran.h"
 
@@ -85,7 +85,7 @@ public:
      //		U32 * fcLim, U32 currentfc, BTE * bte, U32 * pos, int nobte, FILE * fd);
 
      virtual int Convert_first_pass(void);
-     virtual int Dispatch(int FuncNo, ...);
+     virtual int Dispatch(int FuncNo, const void *arg);
      };
 
 /*Register translators here*/
@@ -568,7 +568,7 @@ long currentpos;
 
     if (currentfc == 0xffffffffL)
       {
-      fprintf(stderr,_("Char Bounds not found !\n"));
+      fprintf(stderr,_("Char Bounds not found!\n"));
       return(1);
       }
 
@@ -838,7 +838,7 @@ DWORD begincp, endcp;
 		 wvConvertCPToFC(i, &cq->clx),
 		 cq->btePapx, cq->posPapx, cq->para_intervals, cq->wpd);
 	if(cq->log)
-	   fprintf(cq->log,_("\nPara from %lXh to %lXh, j is %lXh "), cq->para_fcFirst, cq->para_fcLim, cq->ActualPos);
+	   fprintf(cq->log,_("\nPara from %lXh to %lXh, j is %lXh "), cq->para_fcFirst, cq->para_fcLim, (long)cq->ActualPos);
 	if (0 == cq->para_pendingclose)
 	  {  /* if there's no paragraph open, but there should be then I believe that the fcFirst search
 		has failed me, so I set it to now. I need to investigate this further. I believe it occurs
@@ -1408,21 +1408,15 @@ DWORD begincp, endcp;
 }
 
 
-int TconvertedPass1_WORD::Dispatch(int FuncNo, ...)
+int TconvertedPass1_WORD::Dispatch(int FuncNo, const void *arg)
 {
-va_list ap;
-
- va_start(ap, FuncNo);
-
  switch(FuncNo)
    {
    case DISP_WRAPPER:
-	 OleFS = (COLEFS *)va_arg(ap,COLEFS *);
-	 va_end(ap);
+	 OleFS = (COLEFS *)arg;
 	 return 0;
    }
 
- va_end(ap);
 return(-1);
 }
 
@@ -1558,13 +1552,13 @@ string temp_filename;
   if(fib.fcMin<ActualPos || fib.fcMin>fib.fcMac)
 	{
 	if(err != NULL)
-	  {perc.Hide();fprintf(err,_("\nError: FIB.fcMin is corrupted %ld !"),fib.fcMin);}
+	  {perc.Hide();fprintf(err,_("\nError: FIB.fcMin is corrupted %ld!"),fib.fcMin);}
 	fib.fcMin=ActualPos;
 	}
   if(fib.fcMac>fsize)
 	{
 	if(err != NULL)
-	  {perc.Hide();fprintf(err,_("\nError: FIB.fcMac is bigger than file size %ld !"),fib.fcMac);}
+	  {perc.Hide();fprintf(err,_("\nError: FIB.fcMac is bigger than file size %ld!"),fib.fcMac);}
 	fib.fcMac=fsize;
 	}
 
@@ -1590,7 +1584,7 @@ string temp_filename;
 		  if(err != NULL)
 		    {
 		    perc.Hide();
-		    fprintf(err,_("Piece Bounds out of range begin=%ld end=%ld!\n"),beginfc,endfc);
+		    fprintf(err,_("Piece Bounds out of range begin=%ld end=%ld!\n"), (long)beginfc, (long)endfc);
 		    }
 		  if(endfc>fsize) endfc=fsize;	//Try to fix end bound
 		  if(beginfc>endfc) continue;
