@@ -1,6 +1,6 @@
 /******************************************************************************
  * program:     wp2latex                                                      *
- * function:    convert WordPerfect 5.x,6,7,8.x files into LaTeX              *
+ * function:    convert WordPerfect and other text documents into LaTeX       *
  * modul:       pass2.cc                                                      *
  * description: This modul contains functions for second pass. In the second  *
  *              pass the text file stripped from the WP binary file will be   *
@@ -37,8 +37,9 @@ extern list Counters, UserLists;
 #define TABPOS_COUNT	40
 
 /// Attribute for each line of conferted text.
-typedef struct TLinePass2
-  {
+class TLinePass2
+{
+public:
   string Lstring;			///< Text on the line.
   bool new_tabset;
   int tabent_num_of_tabs;
@@ -54,7 +55,7 @@ typedef struct TLinePass2
   int ind_leftmargin;
   signed char Indent_Level;
   WORD tabent_tabpos[TABPOS_COUNT];
-  } TLinePass2;
+};
 
 
 /// Main object that packs all needed stuff for pass2.
@@ -211,7 +212,7 @@ TLinePass2 *pCurLine;
     if(fread(&b, 1, 1, table)==0) // We are probaly at the end of the file
 		break;
 
-    switch (b)
+    switch(b)
 	{
 	case 'B':pCurLine->envir = 'B';    break;
 	case 'C':pCurLine->envir = 'C';    break;
@@ -233,8 +234,15 @@ TLinePass2 *pCurLine;
 		 for(j=0; j<b; j++)
 		     {
 		     Rd_word(table, &w);
-		     pCurLine->tabent_tabpos[j] = w;
+		     if(j<TABPOS_COUNT)
+		       pCurLine->tabent_tabpos[j] = w;
 		     }
+                 if(b>=TABPOS_COUNT)
+                   {
+                   if(err!=NULL)
+		     fprintf(err,_("\nError: tabent_num_of_tabs %d >= TABPOS_COUNT %d!"), pCurLine->tabent_num_of_tabs, TABPOS_COUNT);
+                   pCurLine->tabent_num_of_tabs = TABPOS_COUNT;
+                   }
 		 break;
 
        case 'l': Rd_word(table, &w);
@@ -259,10 +267,16 @@ TLinePass2 *pCurLine;
 	case '^':pCurLine->envir = '^';    break; /* Ignore enviroment after */
 
 		    // Read all opened attributes into attr structure
-	case 0xF0:fread(&b, 1, 1, table);
-		  pCurLine->attr.Opened_Depth=pCurLine->attr.Closed_Depth = b;
-		  for(j = 0; j<b; j++)
-			fread(&(pCurLine->attr.stack[j]), 1, 1, table);
+	case 0xF0:if(fread(&b, 1, 1, table) != 1) 
+		    {b=0xFF;break;}
+		  pCurLine->attr.Opened_Depth = pCurLine->attr.Closed_Depth = b;
+		  for(j=0; j<b; j++)
+                  {
+                    if(j < pCurLine->attr.getStackLimit())
+		      fread(&(pCurLine->attr.stack[j]), 1, 1, table);
+                    else
+                      fseek(table,1,SEEK_CUR);
+                  }
 		  b=0xF0;
 		  break;
 
@@ -695,7 +709,11 @@ const TLinePass2 *pCurLine = &Lines[cur];
 
   if(pCurLine->new_tabset)
     {
-    num_of_tabs = pCurLine->tabent_num_of_tabs;    
+    num_of_tabs = pCurLine->tabent_num_of_tabs;
+    if(num_of_tabs > TABPOS_COUNT)
+    {
+      num_of_tabs = Lines[cur].tabent_num_of_tabs = TABPOS_COUNT;	// fix a problem.
+    }
     for(j=0; j<num_of_tabs; j++)
           tabpos[j] = pCurLine->tabent_tabpos[j];
     }
@@ -1798,7 +1816,7 @@ FixOpen:	  Open_All_Attr(cq2.Lines[cq2.cur].attr,*aLineStr);
 		}
 
 	 if(length(*aLineStr)>0)
-	   if((i=fputs(*aLineStr,cq2.LaTeX))==EOF) /*here is written current line*/
+	   if((i=fputs((*aLineStr)(),cq2.LaTeX))==EOF) /*here is written current line*/
 			{
 			RunError(0x20,"");
 			}
@@ -1904,7 +1922,7 @@ FixOpen:	  Open_All_Attr(cq2.Lines[cq2.cur].attr,*aLineStr);
 		 }
 	     break;
 
-    case 'P':if (cq2.Lines[cq2.next].attr.Opened_Depth>0) /* Attributes are opened */
+    case 'P':if(cq2.Lines[cq2.next].attr.Opened_Depth>0) /* Attributes are opened */
 		     {
 		     Close_All_Attr(cq2.Lines[cq2.next].attr,s); /* close attributes on EOL */
 		     if((cq2.Lines[cq2.pre].Lstring=="") && cq2.Lines[cq2.cur].Empty)
