@@ -1227,6 +1227,7 @@ float Probability=-1;
 
   FilForD.DocumentType = "Unknown type";
   FilForD.Convertor = "";
+  FilForD.Extension = NULL;
   FilForD.DocVersion = 0;
   FilForD.Probability = -1;
   FilForD.DocumentStart = 0;
@@ -1247,8 +1248,8 @@ float Probability=-1;
 
 	if(Probability>FilForD.Probability)
 	  {
-	  FilForD=iFFD;
-          FilForD.Probability=Probability;
+	  FilForD = iFFD;
+          FilForD.Probability = Probability;
 	  }
 	}
      }
@@ -1682,7 +1683,7 @@ int p;
             int i;
             for(i=0; i<sizeof(PkgList)/sizeof(PkgItem); i++)
               {
-              if(!strcmp(name+1, PkgList[i].Name)) break;
+              if(!strcmp(name, PkgList[i].Name)) break;
               }
             if(i<sizeof(PkgList)/sizeof(PkgItem))
               {
