@@ -436,23 +436,21 @@ void ShowCopyright(void)
          "\ncodes (such as Tab, Tab Set), then run it through wp2latex again."));
 
   puts(_("\nThanks to:R.C.Houtepen            for initial WP2LaTeX pascal release (1990)"
-	 "\n	       Rafael Rodriguez Pappa  for several notes and bugfixes"
+	 "\n          Rafael Rodriguez Pappa  for several notes and bugfixes"
 	 "\n          Damil Cavar             for several bugreports"
-	 "\n          Hilmar Preusse          for translating several WP extended chars"
-	 "\n                                  and translating messages to the German"
+	 "\n          Hilmar Preusse          for translating several WP extended chars; creating"
+	 "\n                                  Debian package and translating messages to the German."
 	 "\n          Christoffer Sorensen    for formula conversion related bugreports"
 	 "\n          Aleksey Gulvanjuk       for adding Russian codepages"
 	 "\n          Fridrich Strba          for valuable hints and WP MAC documentation"
 	 "\n          David Derbes            for hints about MAC compilation"
-         "\n          Peter Dyballa           for preparation of MAC binaries and useful"
-         "\n                                  hints."
+         "\n          Peter Dyballa           for preparation of MAC binaries and useful hints."
          "\n          Schobeiri, Taher M.     for donating WP2LaTeX."
 	 "\n          and of course to all authors of previous releases of WP2LaTeX"
 	 "\n"
 	 "\nIf you find this program useful please send me a *POSTCARD* with"
 	 "\ncharacteristic image of your country."
-	 "\nMy address is: Jaroslav Fojtik; Dvouramenna 13; Prague 4; Czech Republic"
-	 "\n                14000"
+	 "\nMy address is: Jaroslav Fojtik; Dvouramenna 13; Prague 4; Czech Republic 14000"
 	 "\n"
 	 "\nAuthor is not liable for any damage of your system or loose of your profit"
 	 "\ncaused by using or not using this program."
