@@ -148,7 +148,33 @@ size_t sz;
     {
     if(feof(in)) break;
     sz = fread(Buff, 1, min(sizeof(Buff),size), in);
-    if(sz==0) break;
+    if(sz==0 || sz>sizeof(Buff)) break;
+    fwrite(Buff,1,sz,out);
+    size -= sz;
+    }
+
+ fclose(out);
+
+return(size);
+}
+
+
+/** This procedure copies 'size' bytes from "Src" file to "Dest".
+ * @return	0-OK; <0 Error;
+ *              -1 Invalid output file; -2 Invalid input file; */
+int CopyFile(FILE *out, FILE *in, long size)
+{
+char Buff[32];
+size_t sz;
+
+ if(out==NULL) return(-1);
+ if(in==NULL) return(-2);
+
+ while(size > 0)
+    {
+    if(feof(in)) break;
+    sz = fread(Buff, 1, min(sizeof(Buff),size), in);
+    if(sz==0 || sz>sizeof(Buff)) break;
     fwrite(Buff,1,sz,out);
     size -= sz;
     }
